@@ -3,17 +3,16 @@ package Alien::Base;
 use strict;
 use warnings;
 
-our $VERSION = '0.001';
+use Alien::Base::PkgConfig;
+
+our $VERSION = '0.002';
 $VERSION = eval $VERSION;
 
 use Carp;
 use DynaLoader ();
 
-use File::chdir;
 use File::ShareDir ();
 use Scalar::Util qw/blessed/;
-use Perl::OSType qw/is_os_type/;
-use Config;
 use Capture::Tiny 0.17 qw/capture_merged/;
 use Text::ParseWords qw/shellwords/;
 
@@ -66,7 +65,10 @@ sub dist_dir {
   $dist =~ s/::/-/g;
 
 
-  my $dist_dir = $class->config('finished_installing') ?  File::ShareDir::dist_dir($dist) : $class->config('working_directory');
+  my $dist_dir = 
+    $class->config('finished_installing') 
+      ? File::ShareDir::dist_dir($dist) 
+      : $class->config('working_directory');
 
   return $dist_dir;
 }
@@ -110,7 +112,9 @@ sub _keyword {
   my $dist_dir = $self->dist_dir;
   my @pc = $self->pkgconfig(@_);
   my @strings = 
-    map { $_->keyword($keyword, { alien_dist_dir => $dist_dir }) }
+    map { $_->keyword($keyword, 
+      #{ pcfiledir => $dist_dir }
+    ) }
     @pc;
 
   return join( ' ', @strings );
@@ -118,8 +122,16 @@ sub _keyword {
 
 sub pkgconfig {
   my $self = shift;
-  my %all = %{ $self->config('pkgconfig') };
-
+  #my %all = %{ $self->config('pkgconfig') };
+  require File::Find;
+  my %all;
+  my $wanted = sub {
+    return if ( -d or not /\.pc$/ );
+    my $pkg = Alien::Base::PkgConfig->new($_);
+    $all{$pkg->{package}} = $pkg;
+  };
+  File::Find::find( $wanted, $self->dist_dir );
+    
   croak "No Alien::Base::PkgConfig objects are stored!"
     unless keys %all;
   
