@@ -3,7 +3,7 @@ package Alien::Base::ModuleBuild;
 use strict;
 use warnings;
 
-our $VERSION = '0.001';
+our $VERSION = '0.002';
 $VERSION = eval $VERSION;
 
 use parent 'Module::Build';
@@ -11,10 +11,12 @@ use parent 'Module::Build';
 use Capture::Tiny 0.17 qw/capture tee/;
 use File::chdir;
 use File::Spec;
+use File::Basename qw/fileparse/;
 use Carp;
 use Archive::Extract;
 use Sort::Versions;
 use List::MoreUtils qw/uniq/;
+use ExtUtils::Installed;
 
 use Alien::Base::PkgConfig;
 use Alien::Base::ModuleBuild::Cabinet;
@@ -129,7 +131,6 @@ sub new {
 
   # setup additional temporary directories, and yes we have to add File::ShareDir manually
   $self->_add_prereq( 'requires', 'File::ShareDir', '1.00' );
-  $self->alien_init_temp_dir;
 
   # force newest for all automated testing 
   #TODO (this probably should be checked for "input needed" rather than blindly assigned)
@@ -187,6 +188,7 @@ sub ACTION_code {
 
 sub ACTION_alien {
   my $self = shift;
+  $self->alien_init_temp_dir;
 
   $self->config_data( name => $self->alien_name );
 
@@ -229,11 +231,14 @@ sub ACTION_alien {
     $self->config_data( working_directory => $extract_path );
     $CWD = $extract_path;
 
-    print "Building library ... ";
-    unless ($self->alien_do_commands('build')) {
-      print "Failed\n";
-      croak "Build not completed";
+    if ( $file->platform eq 'src' ) {
+      print "Building library ... ";
+      unless ($self->alien_do_commands('build')) {
+        print "Failed\n";
+        croak "Build not completed";
+      }
     }
+
     print "Done\n";
 
   }
@@ -275,6 +280,7 @@ sub ACTION_test {
 sub ACTION_install {
   my $self = shift;
   $self->SUPER::ACTION_install;
+  return if $self->config_data( 'install_type' ) eq 'system';
 
   {
     my $target = $self->alien_library_destination;
@@ -295,12 +301,16 @@ sub ACTION_install {
     print "Done\n";
   }
 
+  # refresh metadata after library installation
   $self->alien_refresh_manual_pkgconfig( $self->alien_library_destination );
   $self->config_data( 'finished_installing' => 1 );
 
   # to refresh config_data
   $self->SUPER::ACTION_config_data;
   $self->SUPER::ACTION_install;
+
+  # refresh the packlist
+  $self->alien_refresh_packlist( $self->alien_library_destination );
 }
 
 #######################
@@ -483,7 +493,7 @@ sub alien_load_pkgconfig {
 
   my %pc_objects = map { 
     my $pc = Alien::Base::PkgConfig->new($_);
-    $pc->make_abstract( alien_dist_dir => $dir );
+    $pc->make_abstract( pcfiledir => $dir );
     ($pc->{package}, $pc)
   } @$pc_files;
 
@@ -514,7 +524,7 @@ sub alien_generate_manual_pkgconfig {
   my $paths = $self->alien_find_lib_paths($dir);
 
   my @L = 
-    map { File::Spec->catdir( '-L${alien_dist_dir}', $_ ) }
+    map { File::Spec->catdir( '-L${pcfiledir}', $_ ) }
     @{$paths->{lib}};
 
   my $provides_libs = $self->alien_provides_libs;
@@ -528,7 +538,7 @@ sub alien_generate_manual_pkgconfig {
   my $libs = join( ' ', @L, $provides_libs );
 
   my @I = 
-    map { File::Spec->catdir( '-I${alien_dist_dir}', $_ ) }
+    map { File::Spec->catdir( '-I${pcfiledir}', $_ ) }
     @{$paths->{inc}};
 
   my $provides_cflags = $self->alien_provides_cflags;
@@ -538,7 +548,7 @@ sub alien_generate_manual_pkgconfig {
   my $manual_pc = Alien::Base::PkgConfig->new({
     package  => $self->alien_name,
     vars     => {
-      alien_dist_dir => $dir,
+      pcfiledir => $dir,
     },
     keywords => {
       Cflags  => $cflags || '',
@@ -550,48 +560,79 @@ sub alien_generate_manual_pkgconfig {
   return $manual_pc;
 }
 
+sub _alien_file_pattern {
+  my $self = shift;
+  my $ext = $self->config('so'); #platform specific .so extension
+  return qr/\.[\d.]*(?<=\.)$ext[\d.]*(?<!\.)|\.h$/;
+};
+
 sub alien_find_lib_paths {
   my $self = shift;
   my ($dir) = @_;
 
   my $libs = $self->alien_provides_libs;
   my @libs;
-  @libs = map { /-l(.*)/ ? $1 : () } split /\s+/, $libs if $libs;
-  $libs[0] = '' unless @libs; #find all so files if no provides_libs;
+  @libs = grep { s/^-l// } split /\s+/, $libs if $libs;
 
-  my $ext = $self->config('so'); #platform specific .so extension
+  my $file_pattern = $self->_alien_file_pattern;
 
-  my @so_files = sort #easier testing
-    map { File::Spec->abs2rel( $_, $dir ) } # make relative to $dir
-    map { @{ $self->rscan_dir($dir, qr/$_\.$ext$/) } } #find all .so
-    @libs;
+  my @files =     
+    map { File::Spec->abs2rel( $_, $dir ) }  # make relative to $dir
+    grep { ! -d }
+    @{ $self->rscan_dir( $dir, $file_pattern ) };
 
-  my @lib_paths = uniq
-    map { File::Spec->catdir($_) } # remove trailing /
-    map { ( File::Spec->splitpath($_) )[1] } # get only directory
-    @so_files;
+  my (@so_files, @lib_paths, @inc_paths);
+  for (@files) {
 
-  @so_files = uniq
-    map { 
-      my $file = $_;
-      1 while $file =~ s/\.\d+$//;
-      $file =~ s/^(?:lib)?(.*?)\.$ext$/$1/;
-      1 while $file =~ s/\.\d+$//;
-      $file 
+    my ($file, $path, $ext) = fileparse( $_, $file_pattern );
+    next unless $ext; # just in case
+
+    $path = File::Spec->catdir($path); # remove trailing /
+
+    if ($ext eq '.h') {
+      push @inc_paths, $path;
+      next;
     }
-    map { ( File::Spec->splitpath($_) )[2] } 
-    @so_files;
 
-  my @inc_paths = uniq
-    map { File::Spec->catdir($_) } # remove trailing /
-    map { ( File::Spec->splitpath($_) )[1] } # get only directory
-    map { File::Spec->abs2rel( $_, $dir ) } # make relative to $dir
-    map { @{ $self->rscan_dir($dir, qr/$_\.h$/) } } #find all .so
-    @libs;
+    $file =~ s/^lib//;
+
+    if (@libs) {
+      next unless grep { $file eq $_ } @libs;
+    }
+
+    push @so_files, $file;
+    push @lib_paths, $path;
+  }
+
+  @so_files = uniq @so_files;
+  @so_files = sort @so_files;
+
+  @lib_paths = uniq @lib_paths;
+  @inc_paths = uniq @inc_paths;
 
   return { lib => \@lib_paths, inc => \@inc_paths, so_files => \@so_files };
 }
 
+sub alien_refresh_packlist {
+  my $self = shift;
+  my $dir = shift || croak "Must specify a directory to include in packlist";
+
+  my $inst = ExtUtils::Installed->new;
+  my $packlist = $inst->packlist( $self->module_name );
+  print "Using " .  $packlist->packlist_file . "\n";
+
+  my $changed = 0;
+  my $files = $self->rscan_dir($dir);
+  for my $file (@$files) {
+    next if $packlist->{$file};
+    print "Adding $file to packlist\n"; 
+    $changed++;
+    $packlist->{$file}++;
+  };
+
+  $packlist->write if $changed;
+}
+
 1;
 
 __END__
